summaryrefslogtreecommitdiffstats
path: root/webapp/root.jsx
diff options
context:
space:
mode:
authorJoram Wilander <jwawilander@gmail.com>2016-05-16 19:09:37 -0400
committerCorey Hulen <corey@hulen.com>2016-05-16 16:09:37 -0700
commit34780f3aea78bbf5dd35230ba7ad4a67618b42a0 (patch)
tree760e5130264177763081760865cf109323e393a2 /webapp/root.jsx
parent2ccf5bbaa2421c03cf932431fc0247b43b48d774 (diff)
downloadchat-34780f3aea78bbf5dd35230ba7ad4a67618b42a0.tar.gz
chat-34780f3aea78bbf5dd35230ba7ad4a67618b42a0.tar.bz2
chat-34780f3aea78bbf5dd35230ba7ad4a67618b42a0.zip
Refresh login page if server version of client doesn't match browser version of client (#3004)
Diffstat (limited to 'webapp/root.jsx')
-rw-r--r--webapp/root.jsx4
1 files changed, 3 insertions, 1 deletions
diff --git a/webapp/root.jsx b/webapp/root.jsx
index 2b54c2174..f53109cdd 100644
--- a/webapp/root.jsx
+++ b/webapp/root.jsx
@@ -24,6 +24,7 @@ import * as AsyncClient from 'utils/async_client.jsx';
import ChannelStore from 'stores/channel_store.jsx';
import ErrorStore from 'stores/error_store.jsx';
import TeamStore from 'stores/team_store.jsx';
+import BrowserStore from 'stores/browser_store.jsx';
import * as Utils from 'utils/utils.jsx';
import Client from 'utils/web_client.jsx';
@@ -101,9 +102,10 @@ function preRenderSetup(callwhendone) {
}
);
// Make sure the websockets close
$(window).on('beforeunload',
() => {
+ BrowserStore.setLastServerVersion('');
Websockets.close();
}
);
@@ -101,9 +102,10 @@ function preRenderSetup(callwhendone) {
}
);
- // Make sure the websockets close
+ // Make sure the websockets close and reset version
$(window).on('beforeunload',
() => {